@@ -416,7 +416,7 @@ async def expect_client_event(
     return evt
 
 
-async def test_connect(cfg: Config, conn: TestConnection) -> None:  # noqa: PLR0912,PLR0915
+async def test_connect(cfg: Config, conn: TestConnection) -> None:  # noqa: PLR0915
     """Connect to the stunnel listener, read/write data as requested."""
 
     async def wait() -> None:
